@@ -18,7 +18,7 @@ fieldhash my %stt         => 'stt';
 fieldhash my %transitions => 'transitions';
 fieldhash my %verbose     => 'verbose';
 
-our $VERSION = '1.05';
+our $VERSION = '1.06';
 
 # -----------------------------------------------
 
@@ -48,7 +48,9 @@ sub advance
 
 		if (length($output) >= length($input) )
 		{
-			$self -> log( ($self -> die_on_loop ? 'error' : 'warning') => "State: '" . $self -> current . "' is not consuming input");
+			my($prefix) = $input ? '<' . join('> <', map{$_ ge ' ' && $_ le '~' ? sprintf('%s', $_) : sprintf('0x%02x', ord $_)} grep{/./} split(//, substr($input, 0, 5) ) ) . '>' : '';
+
+			$self -> log( ($self -> die_on_loop ? 'error' : 'warning') => "State: '" . $self -> current . "' is not consuming input. Next 5 chars: $prefix");
 		}
 
 		$input = $output;
@@ -309,14 +311,15 @@ sub log
 	$level   ||= 'debug';
 	$message ||= '';
 
+	if ($level eq 'error')
+	{
+		die $message;
+	}
+
 	if ($self -> logger)
 	{
 		$self -> logger -> $level($message);
 	}
-	elsif ($level eq 'error')
-	{
-		die $message;
-	}
 	elsif ($self -> verbose)
 	{
 		print "$level: $message\n";
